@@ -186,6 +186,7 @@ async def create_device_manager(
     session: aiohttp.ClientSession | None = None,
     ready_callback: DeviceReadyCallback | None = None,
     mqtt_session_unauthorized_hook: SessionUnauthorizedHook | None = None,
+    prefer_cache: bool = True,
 ) -> DeviceManager:
     """Convenience function to create and initialize a DeviceManager.
 
@@ -198,6 +199,7 @@ async def create_device_manager(
         mqtt_session_unauthorized_hook: Optional hook for MQTT session unauthorized
           events which may indicate rate limiting or revoked credentials. The
           caller may use this to refresh authentication tokens as needed.
+        prefer_cache: Whether to prefer cached device data over always fetching it from the API.
 
     Returns:
         An initialized DeviceManager with discovered devices.
@@ -240,9 +242,7 @@ async def create_device_manager(
                 channel = create_mqtt_channel(user_data, mqtt_params, mqtt_session, device)
                 model_part = product.model.split(".")[-1]
                 if "ss" in model_part:
-                    raise UnsupportedDeviceError(
-                        f"Device {device.name} has unsupported version B01 product model {product.model}"
-                    )
+                    trait = b01.q10.create(channel)
                 elif "sc" in model_part:
                     # Q7 devices start with 'sc' in their model naming.
                     trait = b01.q7.create(channel)
@@ -259,5 +259,5 @@ async def create_device_manager(
         return dev
 
     manager = DeviceManager(web_api, device_creator, mqtt_session=mqtt_session, cache=cache, diagnostics=diagnostics)
-    await manager.discover_devices()
+    await manager.discover_devices(prefer_cache)
     return manager
